@@ -39,12 +39,20 @@ class Pymod2PkgTests(unittest.TestCase):
     def test_translation_suse(self):
         self.assertEqual(pymod2pkg.module2package('nova', 'suse'),
                          'openstack-nova')
-        self.assertEqual(pymod2pkg.module2package('python-aodhclient',
+        self.assertEqual(pymod2pkg.module2package('aodhclient',
                                                   'suse'),
                          'python-aodhclient')
+        self.assertEqual(pymod2pkg.module2package('gnocciclient',
+                                                  'suse'),
+                         'python-gnocciclient')
+        self.assertEqual(pymod2pkg.module2package('python-cinderclient',
+                                                  'suse'),
+                         'python-cinderclient')
         self.assertEqual(pymod2pkg.module2package('python-neutronclient',
                                                   'suse'),
                          'python-neutronclient')
+        self.assertEqual(pymod2pkg.module2package('Tempest', 'suse'),
+                         'openstack-tempest')
 
     def test_default_translation_rdo(self):
         self.assertEqual(pymod2pkg.module2package('oslo.db', 'fedora'),
